---
title: Ignore ImageMagick alerts in pipelines
tags:
  - documentation
  - adr
status: "accepted"
date: 2024-11-15
decision-makers: Daniel Speicher, Jürgen Haas
---

# Ignore ImageMagick alerts in pipelines

## Context and Problem Statement

We've received alerts from CI pipelines when end-to-end tests with Cypress wanted to render the link to an embedded PDF
with a thumbnail. The problem was that ImageMagick was called to create the thumbnail, but PDF files are not available
to pipelines, so that an error was logged about that missing file.

## Decision Drivers

Alerts always require attention, and their root cause needs to be fixed. Ignoring alerts is unacceptable.

## Considered Options

* Provide all files from the live site to the pipeline
* Prevent alerts in pipelines generally
* Ignore that specific alert in pipelines
* Ignore that specific alert generally

## Decision Outcome

Chosen option: "Ignore that specific alert generally", because it is acceptable to ignore ImageMagick errors that are
caused by a missing source file.

### Consequences

* Good, because the unnecessary alert will not be created any loinger
* Bad, because we won't get alerts in production, if a thumbnail of a missing file would be requested

## Pros and Cons of the Options

### Provide all files from the live site to the pipeline

* Good, because the pipeline would exactly match the live system and create the greatest possible certainty that the site actually works correctly
* Bad, because the data volume can be far too big to make it available in pipelines

### Prevent alerts in pipelines generally

* Bad, because potential errors would remain unnoticed

### Ignore that specific alert in pipelines

* Good, because it's a known issue that doesn't hurt
* Neutral, because it would require extra complexity to the alert setup to be aware of the stage

### Ignore that specific alert generally

* Good, because it's a known issue that doesn't hurt
* Neutral, because it may theoretically miss a similar alert in production
